RocketException class

Represents an exception that occurs during data loading or manipulation.

Constructors

RocketException({dynamic response = "Check model", int statusCode = 0, String exception = "", StackTrace stackTrace = StackTrace.empty})
Creates a new RocketException.

Properties

exception String
The exception message.
final
hashCode int
The hash code for this object.
no setterinherited
response → dynamic
The response data when the exception occurred.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace
The stack trace.
final
statusCode int
The HTTP status code.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited