rocket_model library
Classes
- RocketException
- Represents an exception that occurs during data loading or manipulation.
- RocketListenable
- An abstract class that defines the behavior of a listenable object.
-
RocketModel<
T> - An abstract class that defines the behavior of a model object.
Enums
Extensions
-
AllToJson
on List<
RocketModel>
Constants
- rocketRebuild → const String
- rocketRequestKey → const String